@@ -28,6 +28,7 @@ class Consumer(Worker):
 
     listeners: dict[str, Callable]
     queue: Queue
+    exceeded_size: int = 65536
 
 
     def __init_subclass__(cls):
@@ -39,7 +40,7 @@ class Consumer(Worker):
 
     def __init__(self):
         super().__init__()
-        self.queue = Queue()
+        self.queue = Queue(self.exceeded_size)
 
 
     async def _mainloop(self):
