@@ -1,4 +1,6 @@
 from multiprocessing import Value
+from queue import Full as QueueIsFull
+
 from functools import cache
 
 from typing import Any, Sequence
@@ -28,15 +30,22 @@ class Producer(Worker):
         """
 
         packet = Packet(event, data)
-        for queue in self._get_queues(event):
-            queue.put(packet)
+        for consumer, queue in self._get_queues(event):
+            try:
+                queue.put(packet, timeout=10)
+            
+            except QueueIsFull:
+                # Stop pushing to this queue again
+                # if it has managed to exceed expected size
+                self.consumers.remove(consumer)
+                self._get_queues.cache_clear()
 
     @cache
     def _get_queues(self, event: str):
         """Get all queues of consumers that have
         an event listener of the specified event type
         """
-        return tuple(consumer.queue for consumer in self.consumers
+        return tuple((consumer, consumer.queue) for consumer in self.consumers
                         if event in consumer.listeners.keys())
 
 
